# coding: utf-8

"""
    Banyan Rest APIs

    This swagger spec contains list of all Banyan APIs.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

from banyanclient.paths.v1_access_tiers_stats.get import V1AccessTiersStatsGet
from banyanclient.paths.v1_one_click_support_bundle.post import V1OneClickSupportBundlePost
from banyanclient.paths.v1_service_hostname_mapping.get import V1ServiceHostnameMappingGet
from banyanclient.paths.v2_access_tier_access_tier_id_tunnel_config_tunnel_config_id.delete import V2AccessTierAccessTierIdTunnelConfigTunnelConfigIdDelete
from banyanclient.paths.v2_access_tier_access_tier_id_tunnel_config_tunnel_config_id.post import V2AccessTierAccessTierIdTunnelConfigTunnelConfigIdPost
from banyanclient.paths.v2_access_tier.get import V2AccessTierGet
from banyanclient.paths.v2_access_tier_id.delete import V2AccessTierIdDelete
from banyanclient.paths.v2_access_tier_id.get import V2AccessTierIdGet
from banyanclient.paths.v2_access_tier_id.put import V2AccessTierIdPut
from banyanclient.paths.v2_access_tier_id_registered_services.get import V2AccessTierIdRegisteredServicesGet
from banyanclient.paths.v2_access_tier.post import V2AccessTierPost


class AccessTierApi(
    V1AccessTiersStatsGet,
    V1OneClickSupportBundlePost,
    V1ServiceHostnameMappingGet,
    V2AccessTierAccessTierIdTunnelConfigTunnelConfigIdDelete,
    V2AccessTierAccessTierIdTunnelConfigTunnelConfigIdPost,
    V2AccessTierGet,
    V2AccessTierIdDelete,
    V2AccessTierIdGet,
    V2AccessTierIdPut,
    V2AccessTierIdRegisteredServicesGet,
    V2AccessTierPost,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

from dataclasses import dataclass
import typing_extensions
import urllib3
from urllib3._collections import HTTPHeaderDict

from banyanclient import api_client, exceptions
from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from banyanclient import schemas  # noqa: F401

from . import path

# query params
ServiceIDSchema = schemas.StrSchema
DefaultServicesSchema = schemas.BoolSchema
ServiceNameSchema = schemas.StrSchema
FriendlyNameSchema = schemas.StrSchema
RequestRequiredQueryParams = typing_extensions.TypedDict(
    'RequestRequiredQueryParams',
    {
    }
)
RequestOptionalQueryParams = typing_extensions.TypedDict(
    'RequestOptionalQueryParams',
    {
        'ServiceID': typing.Union[ServiceIDSchema, str, ],
        'DefaultServices': typing.Union[DefaultServicesSchema, bool, ],
        'ServiceName': typing.Union[ServiceNameSchema, str, ],
        'FriendlyName': typing.Union[FriendlyNameSchema, str, ],
    },
    total=False
)


class RequestQueryParams(RequestRequiredQueryParams, RequestOptionalQueryParams):
    pass


request_query_service_id = api_client.QueryParameter(
    name="ServiceID",
    style=api_client.ParameterStyle.FORM,
    schema=ServiceIDSchema,
    explode=True,
)
request_query_default_services = api_client.QueryParameter(
    name="DefaultServices",
    style=api_client.ParameterStyle.FORM,
    schema=DefaultServicesSchema,
    explode=True,
)
request_query_service_name = api_client.QueryParameter(
    name="ServiceName",
    style=api_client.ParameterStyle.FORM,
    schema=ServiceNameSchema,
    explode=True,
)
request_query_friendly_name = api_client.QueryParameter(
    name="FriendlyName",
    style=api_client.ParameterStyle.FORM,
    schema=FriendlyNameSchema,
    explode=True,
)
_auth = [
    'bearerAuthToken',
]


class SchemaFor200ResponseBodyApplicationJson(
    schemas.ListSchema
):


    class MetaOapg:
        
        
        class items(
            schemas.DictSchema
        ):
        
        
            class MetaOapg:
                
                class properties:
                    ServiceID = schemas.StrSchema
                    ServiceName = schemas.StrSchema
                    FriendlyName = schemas.StrSchema
                    ClusterName = schemas.StrSchema
                    ServiceType = schemas.StrSchema
                    ServiceDiscovery = schemas.StrSchema
                    ServiceVersion = schemas.IntSchema
                    Description = schemas.StrSchema
                    CreatedBy = schemas.StrSchema
                    CreatedAt = schemas.IntSchema
                    LastUpdatedBy = schemas.StrSchema
                    LastUpdatedAt = schemas.IntSchema
                    DeletedBy = schemas.StrSchema
                    DeletedAt = schemas.IntSchema
                    External = schemas.StrSchema
                    OIDCEnabled = schemas.StrSchema
                    OIDCClientSpec = schemas.StrSchema
                    ServiceSpec = schemas.StrSchema
                    UserFacing = schemas.StrSchema
                    Protocol = schemas.StrSchema
                    Domain = schemas.StrSchema
                    Port = schemas.IntSchema
                    Enabled = schemas.StrSchema
                    IsDefault = schemas.BoolSchema
                    __annotations__ = {
                        "ServiceID": ServiceID,
                        "ServiceName": ServiceName,
                        "FriendlyName": FriendlyName,
                        "ClusterName": ClusterName,
                        "ServiceType": ServiceType,
                        "ServiceDiscovery": ServiceDiscovery,
                        "ServiceVersion": ServiceVersion,
                        "Description": Description,
                        "CreatedBy": CreatedBy,
                        "CreatedAt": CreatedAt,
                        "LastUpdatedBy": LastUpdatedBy,
                        "LastUpdatedAt": LastUpdatedAt,
                        "DeletedBy": DeletedBy,
                        "DeletedAt": DeletedAt,
                        "External": External,
                        "OIDCEnabled": OIDCEnabled,
                        "OIDCClientSpec": OIDCClientSpec,
                        "ServiceSpec": ServiceSpec,
                        "UserFacing": UserFacing,
                        "Protocol": Protocol,
                        "Domain": Domain,
                        "Port": Port,
                        "Enabled": Enabled,
                        "IsDefault": IsDefault,
                    }
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["ServiceID"]) -> MetaOapg.properties.ServiceID: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["ServiceName"]) -> MetaOapg.properties.ServiceName: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["FriendlyName"]) -> MetaOapg.properties.FriendlyName: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["ClusterName"]) -> MetaOapg.properties.ClusterName: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["ServiceType"]) -> MetaOapg.properties.ServiceType: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["ServiceDiscovery"]) -> MetaOapg.properties.ServiceDiscovery: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["ServiceVersion"]) -> MetaOapg.properties.ServiceVersion: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["Description"]) -> MetaOapg.properties.Description: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["CreatedBy"]) -> MetaOapg.properties.CreatedBy: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["CreatedAt"]) -> MetaOapg.properties.CreatedAt: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["LastUpdatedBy"]) -> MetaOapg.properties.LastUpdatedBy: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["LastUpdatedAt"]) -> MetaOapg.properties.LastUpdatedAt: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["DeletedBy"]) -> MetaOapg.properties.DeletedBy: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["DeletedAt"]) -> MetaOapg.properties.DeletedAt: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["External"]) -> MetaOapg.properties.External: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["OIDCEnabled"]) -> MetaOapg.properties.OIDCEnabled: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["OIDCClientSpec"]) -> MetaOapg.properties.OIDCClientSpec: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["ServiceSpec"]) -> MetaOapg.properties.ServiceSpec: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["UserFacing"]) -> MetaOapg.properties.UserFacing: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["Protocol"]) -> MetaOapg.properties.Protocol: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["Domain"]) -> MetaOapg.properties.Domain: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["Port"]) -> MetaOapg.properties.Port: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["Enabled"]) -> MetaOapg.properties.Enabled: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["IsDefault"]) -> MetaOapg.properties.IsDefault: ...
            
            @typing.overload
            def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
            
            def __getitem__(self, name: typing.Union[typing_extensions.Literal["ServiceID", "ServiceName", "FriendlyName", "ClusterName", "ServiceType", "ServiceDiscovery", "ServiceVersion", "Description", "CreatedBy", "CreatedAt", "LastUpdatedBy", "LastUpdatedAt", "DeletedBy", "DeletedAt", "External", "OIDCEnabled", "OIDCClientSpec", "ServiceSpec", "UserFacing", "Protocol", "Domain", "Port", "Enabled", "IsDefault", ], str]):
                # dict_instance[name] accessor
                return super().__getitem__(name)
            
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["ServiceID"]) -> typing.Union[MetaOapg.properties.ServiceID, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["ServiceName"]) -> typing.Union[MetaOapg.properties.ServiceName, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["FriendlyName"]) -> typing.Union[MetaOapg.properties.FriendlyName, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["ClusterName"]) -> typing.Union[MetaOapg.properties.ClusterName, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["ServiceType"]) -> typing.Union[MetaOapg.properties.ServiceType, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["ServiceDiscovery"]) -> typing.Union[MetaOapg.properties.ServiceDiscovery, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["ServiceVersion"]) -> typing.Union[MetaOapg.properties.ServiceVersion, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["Description"]) -> typing.Union[MetaOapg.properties.Description, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["CreatedBy"]) -> typing.Union[MetaOapg.properties.CreatedBy, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["CreatedAt"]) -> typing.Union[MetaOapg.properties.CreatedAt, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["LastUpdatedBy"]) -> typing.Union[MetaOapg.properties.LastUpdatedBy, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["LastUpdatedAt"]) -> typing.Union[MetaOapg.properties.LastUpdatedAt, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["DeletedBy"]) -> typing.Union[MetaOapg.properties.DeletedBy, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["DeletedAt"]) -> typing.Union[MetaOapg.properties.DeletedAt, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["External"]) -> typing.Union[MetaOapg.properties.External, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["OIDCEnabled"]) -> typing.Union[MetaOapg.properties.OIDCEnabled, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["OIDCClientSpec"]) -> typing.Union[MetaOapg.properties.OIDCClientSpec, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["ServiceSpec"]) -> typing.Union[MetaOapg.properties.ServiceSpec, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["UserFacing"]) -> typing.Union[MetaOapg.properties.UserFacing, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["Protocol"]) -> typing.Union[MetaOapg.properties.Protocol, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["Domain"]) -> typing.Union[MetaOapg.properties.Domain, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["Port"]) -> typing.Union[MetaOapg.properties.Port, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["Enabled"]) -> typing.Union[MetaOapg.properties.Enabled, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["IsDefault"]) -> typing.Union[MetaOapg.properties.IsDefault, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
            
            def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["ServiceID", "ServiceName", "FriendlyName", "ClusterName", "ServiceType", "ServiceDiscovery", "ServiceVersion", "Description", "CreatedBy", "CreatedAt", "LastUpdatedBy", "LastUpdatedAt", "DeletedBy", "DeletedAt", "External", "OIDCEnabled", "OIDCClientSpec", "ServiceSpec", "UserFacing", "Protocol", "Domain", "Port", "Enabled", "IsDefault", ], str]):
                return super().get_item_oapg(name)
            
        
            def __new__(
                cls,
                *args: typing.Union[dict, frozendict.frozendict, ],
                ServiceID: typing.Union[MetaOapg.properties.ServiceID, str, schemas.Unset] = schemas.unset,
                ServiceName: typing.Union[MetaOapg.properties.ServiceName, str, schemas.Unset] = schemas.unset,
                FriendlyName: typing.Union[MetaOapg.properties.FriendlyName, str, schemas.Unset] = schemas.unset,
                ClusterName: typing.Union[MetaOapg.properties.ClusterName, str, schemas.Unset] = schemas.unset,
                ServiceType: typing.Union[MetaOapg.properties.ServiceType, str, schemas.Unset] = schemas.unset,
                ServiceDiscovery: typing.Union[MetaOapg.properties.ServiceDiscovery, str, schemas.Unset] = schemas.unset,
                ServiceVersion: typing.Union[MetaOapg.properties.ServiceVersion, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                Description: typing.Union[MetaOapg.properties.Description, str, schemas.Unset] = schemas.unset,
                CreatedBy: typing.Union[MetaOapg.properties.CreatedBy, str, schemas.Unset] = schemas.unset,
                CreatedAt: typing.Union[MetaOapg.properties.CreatedAt, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                LastUpdatedBy: typing.Union[MetaOapg.properties.LastUpdatedBy, str, schemas.Unset] = schemas.unset,
                LastUpdatedAt: typing.Union[MetaOapg.properties.LastUpdatedAt, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                DeletedBy: typing.Union[MetaOapg.properties.DeletedBy, str, schemas.Unset] = schemas.unset,
                DeletedAt: typing.Union[MetaOapg.properties.DeletedAt, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                External: typing.Union[MetaOapg.properties.External, str, schemas.Unset] = schemas.unset,
                OIDCEnabled: typing.Union[MetaOapg.properties.OIDCEnabled, str, schemas.Unset] = schemas.unset,
                OIDCClientSpec: typing.Union[MetaOapg.properties.OIDCClientSpec, str, schemas.Unset] = schemas.unset,
                ServiceSpec: typing.Union[MetaOapg.properties.ServiceSpec, str, schemas.Unset] = schemas.unset,
                UserFacing: typing.Union[MetaOapg.properties.UserFacing, str, schemas.Unset] = schemas.unset,
                Protocol: typing.Union[MetaOapg.properties.Protocol, str, schemas.Unset] = schemas.unset,
                Domain: typing.Union[MetaOapg.properties.Domain, str, schemas.Unset] = schemas.unset,
                Port: typing.Union[MetaOapg.properties.Port, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                Enabled: typing.Union[MetaOapg.properties.Enabled, str, schemas.Unset] = schemas.unset,
                IsDefault: typing.Union[MetaOapg.properties.IsDefault, bool, schemas.Unset] = schemas.unset,
                _configuration: typing.Optional[schemas.Configuration] = None,
                **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
            ) -> 'items':
                return super().__new__(
                    cls,
                    *args,
                    ServiceID=ServiceID,
                    ServiceName=ServiceName,
                    FriendlyName=FriendlyName,
                    ClusterName=ClusterName,
                    ServiceType=ServiceType,
                    ServiceDiscovery=ServiceDiscovery,
                    ServiceVersion=ServiceVersion,
                    Description=Description,
                    CreatedBy=CreatedBy,
                    CreatedAt=CreatedAt,
                    LastUpdatedBy=LastUpdatedBy,
                    LastUpdatedAt=LastUpdatedAt,
                    DeletedBy=DeletedBy,
                    DeletedAt=DeletedAt,
                    External=External,
                    OIDCEnabled=OIDCEnabled,
                    OIDCClientSpec=OIDCClientSpec,
                    ServiceSpec=ServiceSpec,
                    UserFacing=UserFacing,
                    Protocol=Protocol,
                    Domain=Domain,
                    Port=Port,
                    Enabled=Enabled,
                    IsDefault=IsDefault,
                    _configuration=_configuration,
                    **kwargs,
                )

    def __new__(
        cls,
        arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]], typing.List[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]]],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'SchemaFor200ResponseBodyApplicationJson':
        return super().__new__(
            cls,
            arg,
            _configuration=_configuration,
        )

    def __getitem__(self, i: int) -> MetaOapg.items:
        return super().__getitem__(i)


@dataclass
class ApiResponseFor200(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor200ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_200 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor200,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor200ResponseBodyApplicationJson),
    },
)
_status_code_to_response = {
    '200': _response_for_200,
}
_all_accept_content_types = (
    'application/json',
)


class BaseApi(api_client.Api):

    def _v1_registered_services_get_oapg(
        self: api_client.Api,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        """
         List services
        :param skip_deserialization: If true then api_response.response will be set but
            api_response.body and api_response.headers will not be deserialized into schema
            class instances
        """
        self._verify_typed_dict_inputs_oapg(RequestQueryParams, query_params)
        used_path = path.value

        prefix_separator_iterator = None
        for parameter in (
            request_query_service_id,
            request_query_default_services,
            request_query_service_name,
            request_query_friendly_name,
        ):
            parameter_data = query_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            if prefix_separator_iterator is None:
                prefix_separator_iterator = parameter.get_prefix_separator_iterator()
            serialized_data = parameter.serialize(parameter_data, prefix_separator_iterator)
            for serialized_value in serialized_data.values():
                used_path += serialized_value

        _headers = HTTPHeaderDict()
        # TODO add cookie handling
        if accept_content_types:
            for accept_content_type in accept_content_types:
                _headers.add('Accept', accept_content_type)

        response = self.api_client.call_api(
            resource_path=used_path,
            method='get'.upper(),
            headers=_headers,
            auth_settings=_auth,
            stream=stream,
            timeout=timeout,
        )

        if skip_deserialization:
            api_response = api_client.ApiResponseWithoutDeserialization(response=response)
        else:
            response_for_status = _status_code_to_response.get(str(response.status))
            if response_for_status:
                api_response = response_for_status.deserialize(response, self.api_client.configuration)
            else:
                api_response = api_client.ApiResponseWithoutDeserialization(response=response)

        if not 200 <= response.status <= 299:
            raise exceptions.ApiException(api_response=api_response)

        return api_response


class V1RegisteredServicesGet(BaseApi):
    # this class is used by api classes that refer to endpoints with operationId fn names

    def v1_registered_services_get(
        self: BaseApi,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        return self._v1_registered_services_get_oapg(
            query_params=query_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


class ApiForget(BaseApi):
    # this class is used by api classes that refer to endpoints by path and http method names

    def get(
        self: BaseApi,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        return self._v1_registered_services_get_oapg(
            query_params=query_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )





from banyanclient.paths.v2_satellite_id.get import ApiForget
from banyanclient.paths.v2_satellite_id.put import ApiForput
from banyanclient.paths.v2_satellite_id.delete import ApiFordelete


class V2SatelliteId(
    ApiForget,
    ApiForput,
    ApiFordelete,
):
    pass



# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

from dataclasses import dataclass
import typing_extensions
import urllib3
from urllib3._collections import HTTPHeaderDict

from banyanclient import api_client, exceptions
from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from banyanclient import schemas  # noqa: F401

from . import path

# query params
SerialNumberSchema = schemas.StrSchema
MaxPerPageSchema = schemas.IntSchema
PageNumberSchema = schemas.IntSchema
StartTimeEndTimeSchema = schemas.StrSchema
RequestRequiredQueryParams = typing_extensions.TypedDict(
    'RequestRequiredQueryParams',
    {
    }
)
RequestOptionalQueryParams = typing_extensions.TypedDict(
    'RequestOptionalQueryParams',
    {
        'SerialNumber': typing.Union[SerialNumberSchema, str, ],
        'MaxPerPage': typing.Union[MaxPerPageSchema, decimal.Decimal, int, ],
        'PageNumber': typing.Union[PageNumberSchema, decimal.Decimal, int, ],
        'StartTime &amp; EndTime': typing.Union[StartTimeEndTimeSchema, str, ],
    },
    total=False
)


class RequestQueryParams(RequestRequiredQueryParams, RequestOptionalQueryParams):
    pass


request_query_serial_number = api_client.QueryParameter(
    name="SerialNumber",
    style=api_client.ParameterStyle.FORM,
    schema=SerialNumberSchema,
    explode=True,
)
request_query_max_per_page = api_client.QueryParameter(
    name="MaxPerPage",
    style=api_client.ParameterStyle.FORM,
    schema=MaxPerPageSchema,
    explode=True,
)
request_query_page_number = api_client.QueryParameter(
    name="PageNumber",
    style=api_client.ParameterStyle.FORM,
    schema=PageNumberSchema,
    explode=True,
)
request_query_start_time__end_time = api_client.QueryParameter(
    name="StartTime &amp; EndTime",
    style=api_client.ParameterStyle.FORM,
    schema=StartTimeEndTimeSchema,
    explode=True,
)
_auth = [
    'bearerAuthToken',
]


class SchemaFor200ResponseBodyApplicationJson(
    schemas.DictSchema
):


    class MetaOapg:
        
        class properties:
            Timezone = schemas.StrSchema
            Region = schemas.StrSchema
            Timestamp = schemas.IntSchema
            Locale = schemas.StrSchema
            Compromised = schemas.StrSchema
            OSVersion = schemas.StrSchema
            SerialNumber = schemas.StrSchema
            Model = schemas.StrSchema
            Latitude = schemas.StrSchema
            Longitude = schemas.StrSchema
            BatteryLevel = schemas.StrSchema
            Name = schemas.StrSchema
            __annotations__ = {
                "Timezone": Timezone,
                "Region": Region,
                "Timestamp": Timestamp,
                "Locale": Locale,
                "Compromised": Compromised,
                "OSVersion": OSVersion,
                "SerialNumber": SerialNumber,
                "Model": Model,
                "Latitude": Latitude,
                "Longitude": Longitude,
                "BatteryLevel": BatteryLevel,
                "Name": Name,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["Timezone"]) -> MetaOapg.properties.Timezone: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["Region"]) -> MetaOapg.properties.Region: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["Timestamp"]) -> MetaOapg.properties.Timestamp: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["Locale"]) -> MetaOapg.properties.Locale: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["Compromised"]) -> MetaOapg.properties.Compromised: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["OSVersion"]) -> MetaOapg.properties.OSVersion: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["SerialNumber"]) -> MetaOapg.properties.SerialNumber: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["Model"]) -> MetaOapg.properties.Model: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["Latitude"]) -> MetaOapg.properties.Latitude: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["Longitude"]) -> MetaOapg.properties.Longitude: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["BatteryLevel"]) -> MetaOapg.properties.BatteryLevel: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["Name"]) -> MetaOapg.properties.Name: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["Timezone", "Region", "Timestamp", "Locale", "Compromised", "OSVersion", "SerialNumber", "Model", "Latitude", "Longitude", "BatteryLevel", "Name", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["Timezone"]) -> typing.Union[MetaOapg.properties.Timezone, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["Region"]) -> typing.Union[MetaOapg.properties.Region, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["Timestamp"]) -> typing.Union[MetaOapg.properties.Timestamp, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["Locale"]) -> typing.Union[MetaOapg.properties.Locale, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["Compromised"]) -> typing.Union[MetaOapg.properties.Compromised, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["OSVersion"]) -> typing.Union[MetaOapg.properties.OSVersion, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["SerialNumber"]) -> typing.Union[MetaOapg.properties.SerialNumber, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["Model"]) -> typing.Union[MetaOapg.properties.Model, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["Latitude"]) -> typing.Union[MetaOapg.properties.Latitude, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["Longitude"]) -> typing.Union[MetaOapg.properties.Longitude, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["BatteryLevel"]) -> typing.Union[MetaOapg.properties.BatteryLevel, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["Name"]) -> typing.Union[MetaOapg.properties.Name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["Timezone", "Region", "Timestamp", "Locale", "Compromised", "OSVersion", "SerialNumber", "Model", "Latitude", "Longitude", "BatteryLevel", "Name", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        Timezone: typing.Union[MetaOapg.properties.Timezone, str, schemas.Unset] = schemas.unset,
        Region: typing.Union[MetaOapg.properties.Region, str, schemas.Unset] = schemas.unset,
        Timestamp: typing.Union[MetaOapg.properties.Timestamp, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        Locale: typing.Union[MetaOapg.properties.Locale, str, schemas.Unset] = schemas.unset,
        Compromised: typing.Union[MetaOapg.properties.Compromised, str, schemas.Unset] = schemas.unset,
        OSVersion: typing.Union[MetaOapg.properties.OSVersion, str, schemas.Unset] = schemas.unset,
        SerialNumber: typing.Union[MetaOapg.properties.SerialNumber, str, schemas.Unset] = schemas.unset,
        Model: typing.Union[MetaOapg.properties.Model, str, schemas.Unset] = schemas.unset,
        Latitude: typing.Union[MetaOapg.properties.Latitude, str, schemas.Unset] = schemas.unset,
        Longitude: typing.Union[MetaOapg.properties.Longitude, str, schemas.Unset] = schemas.unset,
        BatteryLevel: typing.Union[MetaOapg.properties.BatteryLevel, str, schemas.Unset] = schemas.unset,
        Name: typing.Union[MetaOapg.properties.Name, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SchemaFor200ResponseBodyApplicationJson':
        return super().__new__(
            cls,
            *args,
            Timezone=Timezone,
            Region=Region,
            Timestamp=Timestamp,
            Locale=Locale,
            Compromised=Compromised,
            OSVersion=OSVersion,
            SerialNumber=SerialNumber,
            Model=Model,
            Latitude=Latitude,
            Longitude=Longitude,
            BatteryLevel=BatteryLevel,
            Name=Name,
            _configuration=_configuration,
            **kwargs,
        )


@dataclass
class ApiResponseFor200(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor200ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_200 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor200,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor200ResponseBodyApplicationJson),
    },
)


@dataclass
class ApiResponseFor400(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: schemas.Unset = schemas.unset
    headers: schemas.Unset = schemas.unset


_response_for_400 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor400,
)


@dataclass
class ApiResponseFor500(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: schemas.Unset = schemas.unset
    headers: schemas.Unset = schemas.unset


_response_for_500 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor500,
)
_status_code_to_response = {
    '200': _response_for_200,
    '400': _response_for_400,
    '500': _response_for_500,
}
_all_accept_content_types = (
    'application/json',
)


class BaseApi(api_client.Api):

    def _v1_enduser_devices_data_get_oapg(
        self: api_client.Api,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        """
         List End User Devices
        :param skip_deserialization: If true then api_response.response will be set but
            api_response.body and api_response.headers will not be deserialized into schema
            class instances
        """
        self._verify_typed_dict_inputs_oapg(RequestQueryParams, query_params)
        used_path = path.value

        prefix_separator_iterator = None
        for parameter in (
            request_query_serial_number,
            request_query_max_per_page,
            request_query_page_number,
            request_query_start_time__end_time,
        ):
            parameter_data = query_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            if prefix_separator_iterator is None:
                prefix_separator_iterator = parameter.get_prefix_separator_iterator()
            serialized_data = parameter.serialize(parameter_data, prefix_separator_iterator)
            for serialized_value in serialized_data.values():
                used_path += serialized_value

        _headers = HTTPHeaderDict()
        # TODO add cookie handling
        if accept_content_types:
            for accept_content_type in accept_content_types:
                _headers.add('Accept', accept_content_type)

        response = self.api_client.call_api(
            resource_path=used_path,
            method='get'.upper(),
            headers=_headers,
            auth_settings=_auth,
            stream=stream,
            timeout=timeout,
        )

        if skip_deserialization:
            api_response = api_client.ApiResponseWithoutDeserialization(response=response)
        else:
            response_for_status = _status_code_to_response.get(str(response.status))
            if response_for_status:
                api_response = response_for_status.deserialize(response, self.api_client.configuration)
            else:
                api_response = api_client.ApiResponseWithoutDeserialization(response=response)

        if not 200 <= response.status <= 299:
            raise exceptions.ApiException(api_response=api_response)

        return api_response


class V1EnduserDevicesDataGet(BaseApi):
    # this class is used by api classes that refer to endpoints with operationId fn names

    def v1_enduser_devices_data_get(
        self: BaseApi,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        return self._v1_enduser_devices_data_get_oapg(
            query_params=query_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


class ApiForget(BaseApi):
    # this class is used by api classes that refer to endpoints by path and http method names

    def get(
        self: BaseApi,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        return self._v1_enduser_devices_data_get_oapg(
            query_params=query_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )





from banyanclient.paths.v2_access_tier_id.get import ApiForget
from banyanclient.paths.v2_access_tier_id.put import ApiForput
from banyanclient.paths.v2_access_tier_id.delete import ApiFordelete


class V2AccessTierId(
    ApiForget,
    ApiForput,
    ApiFordelete,
):
    pass



# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

from dataclasses import dataclass
import typing_extensions
import urllib3
from urllib3._collections import HTTPHeaderDict

from banyanclient import api_client, exceptions
from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from banyanclient import schemas  # noqa: F401

from . import path

# path params
AccessTierIdSchema = schemas.StrSchema
TunnelConfigIdSchema = schemas.StrSchema
RequestRequiredPathParams = typing_extensions.TypedDict(
    'RequestRequiredPathParams',
    {
        'access_tier_id': typing.Union[AccessTierIdSchema, str, ],
        'tunnel_config_id': typing.Union[TunnelConfigIdSchema, str, ],
    }
)
RequestOptionalPathParams = typing_extensions.TypedDict(
    'RequestOptionalPathParams',
    {
    },
    total=False
)


class RequestPathParams(RequestRequiredPathParams, RequestOptionalPathParams):
    pass


request_path_access_tier_id = api_client.PathParameter(
    name="access_tier_id",
    style=api_client.ParameterStyle.SIMPLE,
    schema=AccessTierIdSchema,
    required=True,
)
request_path_tunnel_config_id = api_client.PathParameter(
    name="tunnel_config_id",
    style=api_client.ParameterStyle.SIMPLE,
    schema=TunnelConfigIdSchema,
    required=True,
)
_auth = [
    'bearerAuthToken',
]


class SchemaFor200ResponseBodyApplicationJson(
    schemas.DictSchema
):


    class MetaOapg:
        
        class properties:
            request_id = schemas.StrSchema
            error_code = schemas.IntSchema
            error_description = schemas.StrSchema
            data = schemas.StrSchema
            __annotations__ = {
                "request_id": request_id,
                "error_code": error_code,
                "error_description": error_description,
                "data": data,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["request_id"]) -> MetaOapg.properties.request_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["error_code"]) -> MetaOapg.properties.error_code: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["error_description"]) -> MetaOapg.properties.error_description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["data"]) -> MetaOapg.properties.data: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["request_id", "error_code", "error_description", "data", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["request_id"]) -> typing.Union[MetaOapg.properties.request_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["error_code"]) -> typing.Union[MetaOapg.properties.error_code, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["error_description"]) -> typing.Union[MetaOapg.properties.error_description, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["data"]) -> typing.Union[MetaOapg.properties.data, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["request_id", "error_code", "error_description", "data", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        request_id: typing.Union[MetaOapg.properties.request_id, str, schemas.Unset] = schemas.unset,
        error_code: typing.Union[MetaOapg.properties.error_code, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        error_description: typing.Union[MetaOapg.properties.error_description, str, schemas.Unset] = schemas.unset,
        data: typing.Union[MetaOapg.properties.data, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SchemaFor200ResponseBodyApplicationJson':
        return super().__new__(
            cls,
            *args,
            request_id=request_id,
            error_code=error_code,
            error_description=error_description,
            data=data,
            _configuration=_configuration,
            **kwargs,
        )


@dataclass
class ApiResponseFor200(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor200ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_200 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor200,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor200ResponseBodyApplicationJson),
    },
)


class SchemaFor400ResponseBodyApplicationJson(
    schemas.DictSchema
):


    class MetaOapg:
        
        class properties:
            request_id = schemas.StrSchema
            error_code = schemas.IntSchema
            error_description = schemas.StrSchema
            data = schemas.IntSchema
            __annotations__ = {
                "request_id": request_id,
                "error_code": error_code,
                "error_description": error_description,
                "data": data,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["request_id"]) -> MetaOapg.properties.request_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["error_code"]) -> MetaOapg.properties.error_code: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["error_description"]) -> MetaOapg.properties.error_description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["data"]) -> MetaOapg.properties.data: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["request_id", "error_code", "error_description", "data", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["request_id"]) -> typing.Union[MetaOapg.properties.request_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["error_code"]) -> typing.Union[MetaOapg.properties.error_code, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["error_description"]) -> typing.Union[MetaOapg.properties.error_description, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["data"]) -> typing.Union[MetaOapg.properties.data, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["request_id", "error_code", "error_description", "data", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        request_id: typing.Union[MetaOapg.properties.request_id, str, schemas.Unset] = schemas.unset,
        error_code: typing.Union[MetaOapg.properties.error_code, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        error_description: typing.Union[MetaOapg.properties.error_description, str, schemas.Unset] = schemas.unset,
        data: typing.Union[MetaOapg.properties.data, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SchemaFor400ResponseBodyApplicationJson':
        return super().__new__(
            cls,
            *args,
            request_id=request_id,
            error_code=error_code,
            error_description=error_description,
            data=data,
            _configuration=_configuration,
            **kwargs,
        )


@dataclass
class ApiResponseFor400(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor400ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_400 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor400,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor400ResponseBodyApplicationJson),
    },
)


@dataclass
class ApiResponseFor401(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: schemas.Unset = schemas.unset
    headers: schemas.Unset = schemas.unset


_response_for_401 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor401,
)


@dataclass
class ApiResponseFor500(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: schemas.Unset = schemas.unset
    headers: schemas.Unset = schemas.unset


_response_for_500 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor500,
)
_status_code_to_response = {
    '200': _response_for_200,
    '400': _response_for_400,
    '401': _response_for_401,
    '500': _response_for_500,
}
_all_accept_content_types = (
    'application/json',
)


class BaseApi(api_client.Api):

    def _v2_access_tier_access_tier_id_tunnel_config_tunnel_config_id_post_oapg(
        self: api_client.Api,
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        """
         attach tunnel config to access tier.
        :param skip_deserialization: If true then api_response.response will be set but
            api_response.body and api_response.headers will not be deserialized into schema
            class instances
        """
        self._verify_typed_dict_inputs_oapg(RequestPathParams, path_params)
        used_path = path.value

        _path_params = {}
        for parameter in (
            request_path_access_tier_id,
            request_path_tunnel_config_id,
        ):
            parameter_data = path_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            serialized_data = parameter.serialize(parameter_data)
            _path_params.update(serialized_data)

        for k, v in _path_params.items():
            used_path = used_path.replace('{%s}' % k, v)

        _headers = HTTPHeaderDict()
        # TODO add cookie handling
        if accept_content_types:
            for accept_content_type in accept_content_types:
                _headers.add('Accept', accept_content_type)

        response = self.api_client.call_api(
            resource_path=used_path,
            method='post'.upper(),
            headers=_headers,
            auth_settings=_auth,
            stream=stream,
            timeout=timeout,
        )

        if skip_deserialization:
            api_response = api_client.ApiResponseWithoutDeserialization(response=response)
        else:
            response_for_status = _status_code_to_response.get(str(response.status))
            if response_for_status:
                api_response = response_for_status.deserialize(response, self.api_client.configuration)
            else:
                api_response = api_client.ApiResponseWithoutDeserialization(response=response)

        if not 200 <= response.status <= 299:
            raise exceptions.ApiException(api_response=api_response)

        return api_response


class V2AccessTierAccessTierIdTunnelConfigTunnelConfigIdPost(BaseApi):
    # this class is used by api classes that refer to endpoints with operationId fn names

    def v2_access_tier_access_tier_id_tunnel_config_tunnel_config_id_post(
        self: BaseApi,
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        return self._v2_access_tier_access_tier_id_tunnel_config_tunnel_config_id_post_oapg(
            path_params=path_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


class ApiForpost(BaseApi):
    # this class is used by api classes that refer to endpoints by path and http method names

    def post(
        self: BaseApi,
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        return self._v2_access_tier_access_tier_id_tunnel_config_tunnel_config_id_post_oapg(
            path_params=path_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )





# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

from dataclasses import dataclass
import typing_extensions
import urllib3
from urllib3._collections import HTTPHeaderDict

from banyanclient import api_client, exceptions
from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from banyanclient import schemas  # noqa: F401

from . import path

# query params
SerialNumberSchema = schemas.StrSchema
EmailSchema = schemas.StrSchema
NameSchema = schemas.StrSchema
ActiveSchema = schemas.BoolSchema
RequestRequiredQueryParams = typing_extensions.TypedDict(
    'RequestRequiredQueryParams',
    {
    }
)
RequestOptionalQueryParams = typing_extensions.TypedDict(
    'RequestOptionalQueryParams',
    {
        'serial_number': typing.Union[SerialNumberSchema, str, ],
        'email': typing.Union[EmailSchema, str, ],
        'name': typing.Union[NameSchema, str, ],
        'active': typing.Union[ActiveSchema, bool, ],
    },
    total=False
)


class RequestQueryParams(RequestRequiredQueryParams, RequestOptionalQueryParams):
    pass


request_query_serial_number = api_client.QueryParameter(
    name="serial_number",
    style=api_client.ParameterStyle.FORM,
    schema=SerialNumberSchema,
    explode=True,
)
request_query_email = api_client.QueryParameter(
    name="email",
    style=api_client.ParameterStyle.FORM,
    schema=EmailSchema,
    explode=True,
)
request_query_name = api_client.QueryParameter(
    name="name",
    style=api_client.ParameterStyle.FORM,
    schema=NameSchema,
    explode=True,
)
request_query_active = api_client.QueryParameter(
    name="active",
    style=api_client.ParameterStyle.FORM,
    schema=ActiveSchema,
    explode=True,
)
_auth = [
    'bearerAuthToken',
]


class SchemaFor200ResponseBodyTextCsv(
    schemas.DictSchema
):


    class MetaOapg:
        
        class properties:
            Email = schemas.StrSchema
            created_at = schemas.StrSchema
            last_login = schemas.StrSchema
            login_count = schemas.IntSchema
            serial_numbers = schemas.StrSchema
            Roles = schemas.StrSchema
            Groups = schemas.StrSchema
            TrustData = schemas.IntSchema
            Status = schemas.StrSchema
            archived_at = schemas.StrSchema
            __annotations__ = {
                "Email": Email,
                "Created At": created_at,
                "Last Login": last_login,
                "Login Count": login_count,
                "Serial Numbers": serial_numbers,
                "Roles": Roles,
                "Groups": Groups,
                "TrustData": TrustData,
                "Status": Status,
                "Archived At": archived_at,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["Email"]) -> MetaOapg.properties.Email: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["Created At"]) -> MetaOapg.properties.created_at: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["Last Login"]) -> MetaOapg.properties.last_login: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["Login Count"]) -> MetaOapg.properties.login_count: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["Serial Numbers"]) -> MetaOapg.properties.serial_numbers: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["Roles"]) -> MetaOapg.properties.Roles: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["Groups"]) -> MetaOapg.properties.Groups: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["TrustData"]) -> MetaOapg.properties.TrustData: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["Status"]) -> MetaOapg.properties.Status: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["Archived At"]) -> MetaOapg.properties.archived_at: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["Email", "Created At", "Last Login", "Login Count", "Serial Numbers", "Roles", "Groups", "TrustData", "Status", "Archived At", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["Email"]) -> typing.Union[MetaOapg.properties.Email, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["Created At"]) -> typing.Union[MetaOapg.properties.created_at, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["Last Login"]) -> typing.Union[MetaOapg.properties.last_login, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["Login Count"]) -> typing.Union[MetaOapg.properties.login_count, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["Serial Numbers"]) -> typing.Union[MetaOapg.properties.serial_numbers, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["Roles"]) -> typing.Union[MetaOapg.properties.Roles, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["Groups"]) -> typing.Union[MetaOapg.properties.Groups, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["TrustData"]) -> typing.Union[MetaOapg.properties.TrustData, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["Status"]) -> typing.Union[MetaOapg.properties.Status, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["Archived At"]) -> typing.Union[MetaOapg.properties.archived_at, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["Email", "Created At", "Last Login", "Login Count", "Serial Numbers", "Roles", "Groups", "TrustData", "Status", "Archived At", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        Email: typing.Union[MetaOapg.properties.Email, str, schemas.Unset] = schemas.unset,
        Roles: typing.Union[MetaOapg.properties.Roles, str, schemas.Unset] = schemas.unset,
        Groups: typing.Union[MetaOapg.properties.Groups, str, schemas.Unset] = schemas.unset,
        TrustData: typing.Union[MetaOapg.properties.TrustData, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        Status: typing.Union[MetaOapg.properties.Status, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SchemaFor200ResponseBodyTextCsv':
        return super().__new__(
            cls,
            *args,
            Email=Email,
            Roles=Roles,
            Groups=Groups,
            TrustData=TrustData,
            Status=Status,
            _configuration=_configuration,
            **kwargs,
        )


@dataclass
class ApiResponseFor200(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor200ResponseBodyTextCsv,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_200 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor200,
    content={
        'text/csv': api_client.MediaType(
            schema=SchemaFor200ResponseBodyTextCsv),
    },
)


@dataclass
class ApiResponseFor400(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: schemas.Unset = schemas.unset
    headers: schemas.Unset = schemas.unset


_response_for_400 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor400,
)


@dataclass
class ApiResponseFor500(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: schemas.Unset = schemas.unset
    headers: schemas.Unset = schemas.unset


_response_for_500 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor500,
)
_status_code_to_response = {
    '200': _response_for_200,
    '400': _response_for_400,
    '500': _response_for_500,
}
_all_accept_content_types = (
    'text/csv',
)


class BaseApi(api_client.Api):

    def _v1_endusers_csv_get_oapg(
        self: api_client.Api,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        """
        :param skip_deserialization: If true then api_response.response will be set but
            api_response.body and api_response.headers will not be deserialized into schema
            class instances
        """
        self._verify_typed_dict_inputs_oapg(RequestQueryParams, query_params)
        used_path = path.value

        prefix_separator_iterator = None
        for parameter in (
            request_query_serial_number,
            request_query_email,
            request_query_name,
            request_query_active,
        ):
            parameter_data = query_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            if prefix_separator_iterator is None:
                prefix_separator_iterator = parameter.get_prefix_separator_iterator()
            serialized_data = parameter.serialize(parameter_data, prefix_separator_iterator)
            for serialized_value in serialized_data.values():
                used_path += serialized_value

        _headers = HTTPHeaderDict()
        # TODO add cookie handling
        if accept_content_types:
            for accept_content_type in accept_content_types:
                _headers.add('Accept', accept_content_type)

        response = self.api_client.call_api(
            resource_path=used_path,
            method='get'.upper(),
            headers=_headers,
            auth_settings=_auth,
            stream=stream,
            timeout=timeout,
        )

        if skip_deserialization:
            api_response = api_client.ApiResponseWithoutDeserialization(response=response)
        else:
            response_for_status = _status_code_to_response.get(str(response.status))
            if response_for_status:
                api_response = response_for_status.deserialize(response, self.api_client.configuration)
            else:
                api_response = api_client.ApiResponseWithoutDeserialization(response=response)

        if not 200 <= response.status <= 299:
            raise exceptions.ApiException(api_response=api_response)

        return api_response


class V1EndusersCsvGet(BaseApi):
    # this class is used by api classes that refer to endpoints with operationId fn names

    def v1_endusers_csv_get(
        self: BaseApi,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        return self._v1_endusers_csv_get_oapg(
            query_params=query_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


class ApiForget(BaseApi):
    # this class is used by api classes that refer to endpoints by path and http method names

    def get(
        self: BaseApi,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        return self._v1_endusers_csv_get_oapg(
            query_params=query_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )





# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

from dataclasses import dataclass
import typing_extensions
import urllib3
from urllib3._collections import HTTPHeaderDict

from banyanclient import api_client, exceptions
from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from banyanclient import schemas  # noqa: F401

from . import path

# query params
SerialNumberSchema = schemas.StrSchema
EmailSchema = schemas.StrSchema
NameSchema = schemas.StrSchema
ModelSchema = schemas.StrSchema
PlatformSchema = schemas.StrSchema
TrustLevelSchema = schemas.StrSchema
IdSchema = schemas.StrSchema
OwnershipSchema = schemas.StrSchema
SourceSchema = schemas.StrSchema
ArchitectureSchema = schemas.StrSchema
OsSchema = schemas.StrSchema
MdmPresentSchema = schemas.BoolSchema
MdmVendorNameSchema = schemas.StrSchema
BannedSchema = schemas.BoolSchema
AppVersionSchema = schemas.StrSchema
RoleNamesSchema = schemas.StrSchema
SkipDefault0Schema = schemas.IntSchema
LimitDefault10Schema = schemas.IntSchema
OrderDefaultdescSchema = schemas.StrSchema
OrderByDefaultcreatedAtSchema = schemas.StrSchema
LastLoginBeforeSchema = schemas.IntSchema
LastLoginAfterSchema = schemas.IntSchema
TrustscoreStatusSchema = schemas.StrSchema
ExactEmailSchema = schemas.StrSchema
ExactSerialNumberSchema = schemas.StrSchema
RequestRequiredQueryParams = typing_extensions.TypedDict(
    'RequestRequiredQueryParams',
    {
    }
)
RequestOptionalQueryParams = typing_extensions.TypedDict(
    'RequestOptionalQueryParams',
    {
        'serial_number': typing.Union[SerialNumberSchema, str, ],
        'email': typing.Union[EmailSchema, str, ],
        'name': typing.Union[NameSchema, str, ],
        'model': typing.Union[ModelSchema, str, ],
        'platform': typing.Union[PlatformSchema, str, ],
        'trust_level': typing.Union[TrustLevelSchema, str, ],
        'id': typing.Union[IdSchema, str, ],
        'ownership': typing.Union[OwnershipSchema, str, ],
        'source': typing.Union[SourceSchema, str, ],
        'architecture': typing.Union[ArchitectureSchema, str, ],
        'os': typing.Union[OsSchema, str, ],
        'mdm_present': typing.Union[MdmPresentSchema, bool, ],
        'mdm_vendor_name': typing.Union[MdmVendorNameSchema, str, ],
        'banned': typing.Union[BannedSchema, bool, ],
        'app_version': typing.Union[AppVersionSchema, str, ],
        'role_names': typing.Union[RoleNamesSchema, str, ],
        'skip (default&#x3D;0)': typing.Union[SkipDefault0Schema, decimal.Decimal, int, ],
        'limit (default&#x3D;10)': typing.Union[LimitDefault10Schema, decimal.Decimal, int, ],
        'order (default&#x3D;desc)': typing.Union[OrderDefaultdescSchema, str, ],
        'order_by (default&#x3D;created_at)': typing.Union[OrderByDefaultcreatedAtSchema, str, ],
        'last_login_before': typing.Union[LastLoginBeforeSchema, decimal.Decimal, int, ],
        'last_login_after': typing.Union[LastLoginAfterSchema, decimal.Decimal, int, ],
        'trustscore_status': typing.Union[TrustscoreStatusSchema, str, ],
        'exact_email': typing.Union[ExactEmailSchema, str, ],
        'exact_serial_number': typing.Union[ExactSerialNumberSchema, str, ],
    },
    total=False
)


class RequestQueryParams(RequestRequiredQueryParams, RequestOptionalQueryParams):
    pass


request_query_serial_number = api_client.QueryParameter(
    name="serial_number",
    style=api_client.ParameterStyle.FORM,
    schema=SerialNumberSchema,
    explode=True,
)
request_query_email = api_client.QueryParameter(
    name="email",
    style=api_client.ParameterStyle.FORM,
    schema=EmailSchema,
    explode=True,
)
request_query_name = api_client.QueryParameter(
    name="name",
    style=api_client.ParameterStyle.FORM,
    schema=NameSchema,
    explode=True,
)
request_query_model = api_client.QueryParameter(
    name="model",
    style=api_client.ParameterStyle.FORM,
    schema=ModelSchema,
    explode=True,
)
request_query_platform = api_client.QueryParameter(
    name="platform",
    style=api_client.ParameterStyle.FORM,
    schema=PlatformSchema,
    explode=True,
)
request_query_trust_level = api_client.QueryParameter(
    name="trust_level",
    style=api_client.ParameterStyle.FORM,
    schema=TrustLevelSchema,
    explode=True,
)
request_query_id = api_client.QueryParameter(
    name="id",
    style=api_client.ParameterStyle.FORM,
    schema=IdSchema,
    explode=True,
)
request_query_ownership = api_client.QueryParameter(
    name="ownership",
    style=api_client.ParameterStyle.FORM,
    schema=OwnershipSchema,
    explode=True,
)
request_query_source = api_client.QueryParameter(
    name="source",
    style=api_client.ParameterStyle.FORM,
    schema=SourceSchema,
    explode=True,
)
request_query_architecture = api_client.QueryParameter(
    name="architecture",
    style=api_client.ParameterStyle.FORM,
    schema=ArchitectureSchema,
    explode=True,
)
request_query_os = api_client.QueryParameter(
    name="os",
    style=api_client.ParameterStyle.FORM,
    schema=OsSchema,
    explode=True,
)
request_query_mdm_present = api_client.QueryParameter(
    name="mdm_present",
    style=api_client.ParameterStyle.FORM,
    schema=MdmPresentSchema,
    explode=True,
)
request_query_mdm_vendor_name = api_client.QueryParameter(
    name="mdm_vendor_name",
    style=api_client.ParameterStyle.FORM,
    schema=MdmVendorNameSchema,
    explode=True,
)
request_query_banned = api_client.QueryParameter(
    name="banned",
    style=api_client.ParameterStyle.FORM,
    schema=BannedSchema,
    explode=True,
)
request_query_app_version = api_client.QueryParameter(
    name="app_version",
    style=api_client.ParameterStyle.FORM,
    schema=AppVersionSchema,
    explode=True,
)
request_query_role_names = api_client.QueryParameter(
    name="role_names",
    style=api_client.ParameterStyle.FORM,
    schema=RoleNamesSchema,
    explode=True,
)
request_query_skip__default0 = api_client.QueryParameter(
    name="skip (default&#x3D;0)",
    style=api_client.ParameterStyle.FORM,
    schema=SkipDefault0Schema,
    explode=True,
)
request_query_limit__default10 = api_client.QueryParameter(
    name="limit (default&#x3D;10)",
    style=api_client.ParameterStyle.FORM,
    schema=LimitDefault10Schema,
    explode=True,
)
request_query_order__defaultdesc = api_client.QueryParameter(
    name="order (default&#x3D;desc)",
    style=api_client.ParameterStyle.FORM,
    schema=OrderDefaultdescSchema,
    explode=True,
)
request_query_order_by__defaultcreated_at = api_client.QueryParameter(
    name="order_by (default&#x3D;created_at)",
    style=api_client.ParameterStyle.FORM,
    schema=OrderByDefaultcreatedAtSchema,
    explode=True,
)
request_query_last_login_before = api_client.QueryParameter(
    name="last_login_before",
    style=api_client.ParameterStyle.FORM,
    schema=LastLoginBeforeSchema,
    explode=True,
)
request_query_last_login_after = api_client.QueryParameter(
    name="last_login_after",
    style=api_client.ParameterStyle.FORM,
    schema=LastLoginAfterSchema,
    explode=True,
)
request_query_trustscore_status = api_client.QueryParameter(
    name="trustscore_status",
    style=api_client.ParameterStyle.FORM,
    schema=TrustscoreStatusSchema,
    explode=True,
)
request_query_exact_email = api_client.QueryParameter(
    name="exact_email",
    style=api_client.ParameterStyle.FORM,
    schema=ExactEmailSchema,
    explode=True,
)
request_query_exact_serial_number = api_client.QueryParameter(
    name="exact_serial_number",
    style=api_client.ParameterStyle.FORM,
    schema=ExactSerialNumberSchema,
    explode=True,
)
_auth = [
    'bearerAuthToken',
]


class SchemaFor200ResponseBodyApplicationJson(
    schemas.DictSchema
):


    class MetaOapg:
        
        class properties:
            request_id = schemas.StrSchema
            error_code = schemas.IntSchema
            error_description = schemas.StrSchema
            
            
            class data(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    
                    class properties:
                        
                        
                        class devices(
                            schemas.ListSchema
                        ):
                        
                        
                            class MetaOapg:
                                
                                
                                class items(
                                    schemas.DictSchema
                                ):
                                
                                
                                    class MetaOapg:
                                        
                                        class properties:
                                            id = schemas.StrSchema
                                            serial_number = schemas.StrSchema
                                            name = schemas.StrSchema
                                            model = schemas.StrSchema
                                            ownership = schemas.StrSchema
                                            platform = schemas.StrSchema
                                            architechture = schemas.StrSchema
                                            source = schemas.StrSchema
                                            banned = schemas.IntSchema
                                            os = schemas.StrSchema
                                            mdm_present = schemas.IntSchema
                                            mdm_vendor_name = schemas.StrSchema
                                            mdm_vendor_udid = schemas.StrSchema
                                            mdm_compliant = schemas.StrSchema
                                            app_version = schemas.StrSchema
                                            created_at = schemas.IntSchema
                                            last_login = schemas.IntSchema
                                            
                                            
                                            class extra_details(
                                                schemas.DictSchema
                                            ):
                                            
                                            
                                                class MetaOapg:
                                                    
                                                    class properties:
                                                        
                                                        
                                                        class trust(
                                                            schemas.DictSchema
                                                        ):
                                                        
                                                        
                                                            class MetaOapg:
                                                                
                                                                class properties:
                                                                    value = schemas.IntSchema
                                                                    level = schemas.StrSchema
                                                                    status = schemas.StrSchema
                                                                    
                                                                    
                                                                    class last_evaluated(
                                                                        schemas.DictSchema
                                                                    ):
                                                                    
                                                                    
                                                                        class MetaOapg:
                                                                            
                                                                            class properties:
                                                                                last_evaluated_at = schemas.IntSchema
                                                                                last_evaluated_value = schemas.IntSchema
                                                                                last_evaluated_level = schemas.StrSchema
                                                                                
                                                                                
                                                                                class last_evaluated_factors(
                                                                                    schemas.ListSchema
                                                                                ):
                                                                                
                                                                                
                                                                                    class MetaOapg:
                                                                                        
                                                                                        
                                                                                        class items(
                                                                                            schemas.DictSchema
                                                                                        ):
                                                                                        
                                                                                        
                                                                                            class MetaOapg:
                                                                                                
                                                                                                class properties:
                                                                                                    name = schemas.StrSchema
                                                                                                    value = schemas.StrSchema
                                                                                                    type = schemas.StrSchema
                                                                                                    source = schemas.StrSchema
                                                                                                    description = schemas.StrSchema
                                                                                                    
                                                                                                    
                                                                                                    class remediation(
                                                                                                        schemas.DictSchema
                                                                                                    ):
                                                                                                    
                                                                                                    
                                                                                                        class MetaOapg:
                                                                                                            
                                                                                                            class properties:
                                                                                                                description = schemas.StrSchema
                                                                                                                url = schemas.StrSchema
                                                                                                                __annotations__ = {
                                                                                                                    "description": description,
                                                                                                                    "url": url,
                                                                                                                }
                                                                                                        
                                                                                                        @typing.overload
                                                                                                        def __getitem__(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
                                                                                                        
                                                                                                        @typing.overload
                                                                                                        def __getitem__(self, name: typing_extensions.Literal["url"]) -> MetaOapg.properties.url: ...
                                                                                                        
                                                                                                        @typing.overload
                                                                                                        def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                                                                                                        
                                                                                                        def __getitem__(self, name: typing.Union[typing_extensions.Literal["description", "url", ], str]):
                                                                                                            # dict_instance[name] accessor
                                                                                                            return super().__getitem__(name)
                                                                                                        
                                                                                                        
                                                                                                        @typing.overload
                                                                                                        def get_item_oapg(self, name: typing_extensions.Literal["description"]) -> typing.Union[MetaOapg.properties.description, schemas.Unset]: ...
                                                                                                        
                                                                                                        @typing.overload
                                                                                                        def get_item_oapg(self, name: typing_extensions.Literal["url"]) -> typing.Union[MetaOapg.properties.url, schemas.Unset]: ...
                                                                                                        
                                                                                                        @typing.overload
                                                                                                        def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                                                                                                        
                                                                                                        def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["description", "url", ], str]):
                                                                                                            return super().get_item_oapg(name)
                                                                                                        
                                                                                                    
                                                                                                        def __new__(
                                                                                                            cls,
                                                                                                            *args: typing.Union[dict, frozendict.frozendict, ],
                                                                                                            description: typing.Union[MetaOapg.properties.description, str, schemas.Unset] = schemas.unset,
                                                                                                            url: typing.Union[MetaOapg.properties.url, str, schemas.Unset] = schemas.unset,
                                                                                                            _configuration: typing.Optional[schemas.Configuration] = None,
                                                                                                            **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                                                                                                        ) -> 'remediation':
                                                                                                            return super().__new__(
                                                                                                                cls,
                                                                                                                *args,
                                                                                                                description=description,
                                                                                                                url=url,
                                                                                                                _configuration=_configuration,
                                                                                                                **kwargs,
                                                                                                            )
                                                                                                    __annotations__ = {
                                                                                                        "name": name,
                                                                                                        "value": value,
                                                                                                        "type": type,
                                                                                                        "source": source,
                                                                                                        "description": description,
                                                                                                        "remediation": remediation,
                                                                                                    }
                                                                                            
                                                                                            @typing.overload
                                                                                            def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
                                                                                            
                                                                                            @typing.overload
                                                                                            def __getitem__(self, name: typing_extensions.Literal["value"]) -> MetaOapg.properties.value: ...
                                                                                            
                                                                                            @typing.overload
                                                                                            def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
                                                                                            
                                                                                            @typing.overload
                                                                                            def __getitem__(self, name: typing_extensions.Literal["source"]) -> MetaOapg.properties.source: ...
                                                                                            
                                                                                            @typing.overload
                                                                                            def __getitem__(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
                                                                                            
                                                                                            @typing.overload
                                                                                            def __getitem__(self, name: typing_extensions.Literal["remediation"]) -> MetaOapg.properties.remediation: ...
                                                                                            
                                                                                            @typing.overload
                                                                                            def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                                                                                            
                                                                                            def __getitem__(self, name: typing.Union[typing_extensions.Literal["name", "value", "type", "source", "description", "remediation", ], str]):
                                                                                                # dict_instance[name] accessor
                                                                                                return super().__getitem__(name)
                                                                                            
                                                                                            
                                                                                            @typing.overload
                                                                                            def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> typing.Union[MetaOapg.properties.name, schemas.Unset]: ...
                                                                                            
                                                                                            @typing.overload
                                                                                            def get_item_oapg(self, name: typing_extensions.Literal["value"]) -> typing.Union[MetaOapg.properties.value, schemas.Unset]: ...
                                                                                            
                                                                                            @typing.overload
                                                                                            def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> typing.Union[MetaOapg.properties.type, schemas.Unset]: ...
                                                                                            
                                                                                            @typing.overload
                                                                                            def get_item_oapg(self, name: typing_extensions.Literal["source"]) -> typing.Union[MetaOapg.properties.source, schemas.Unset]: ...
                                                                                            
                                                                                            @typing.overload
                                                                                            def get_item_oapg(self, name: typing_extensions.Literal["description"]) -> typing.Union[MetaOapg.properties.description, schemas.Unset]: ...
                                                                                            
                                                                                            @typing.overload
                                                                                            def get_item_oapg(self, name: typing_extensions.Literal["remediation"]) -> typing.Union[MetaOapg.properties.remediation, schemas.Unset]: ...
                                                                                            
                                                                                            @typing.overload
                                                                                            def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                                                                                            
                                                                                            def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["name", "value", "type", "source", "description", "remediation", ], str]):
                                                                                                return super().get_item_oapg(name)
                                                                                            
                                                                                        
                                                                                            def __new__(
                                                                                                cls,
                                                                                                *args: typing.Union[dict, frozendict.frozendict, ],
                                                                                                name: typing.Union[MetaOapg.properties.name, str, schemas.Unset] = schemas.unset,
                                                                                                value: typing.Union[MetaOapg.properties.value, str, schemas.Unset] = schemas.unset,
                                                                                                type: typing.Union[MetaOapg.properties.type, str, schemas.Unset] = schemas.unset,
                                                                                                source: typing.Union[MetaOapg.properties.source, str, schemas.Unset] = schemas.unset,
                                                                                                description: typing.Union[MetaOapg.properties.description, str, schemas.Unset] = schemas.unset,
                                                                                                remediation: typing.Union[MetaOapg.properties.remediation, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
                                                                                                _configuration: typing.Optional[schemas.Configuration] = None,
                                                                                                **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                                                                                            ) -> 'items':
                                                                                                return super().__new__(
                                                                                                    cls,
                                                                                                    *args,
                                                                                                    name=name,
                                                                                                    value=value,
                                                                                                    type=type,
                                                                                                    source=source,
                                                                                                    description=description,
                                                                                                    remediation=remediation,
                                                                                                    _configuration=_configuration,
                                                                                                    **kwargs,
                                                                                                )
                                                                                
                                                                                    def __new__(
                                                                                        cls,
                                                                                        arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]], typing.List[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]]],
                                                                                        _configuration: typing.Optional[schemas.Configuration] = None,
                                                                                    ) -> 'last_evaluated_factors':
                                                                                        return super().__new__(
                                                                                            cls,
                                                                                            arg,
                                                                                            _configuration=_configuration,
                                                                                        )
                                                                                
                                                                                    def __getitem__(self, i: int) -> MetaOapg.items:
                                                                                        return super().__getitem__(i)
                                                                                __annotations__ = {
                                                                                    "last_evaluated_at": last_evaluated_at,
                                                                                    "last_evaluated_value": last_evaluated_value,
                                                                                    "last_evaluated_level": last_evaluated_level,
                                                                                    "last_evaluated_factors": last_evaluated_factors,
                                                                                }
                                                                        
                                                                        @typing.overload
                                                                        def __getitem__(self, name: typing_extensions.Literal["last_evaluated_at"]) -> MetaOapg.properties.last_evaluated_at: ...
                                                                        
                                                                        @typing.overload
                                                                        def __getitem__(self, name: typing_extensions.Literal["last_evaluated_value"]) -> MetaOapg.properties.last_evaluated_value: ...
                                                                        
                                                                        @typing.overload
                                                                        def __getitem__(self, name: typing_extensions.Literal["last_evaluated_level"]) -> MetaOapg.properties.last_evaluated_level: ...
                                                                        
                                                                        @typing.overload
                                                                        def __getitem__(self, name: typing_extensions.Literal["last_evaluated_factors"]) -> MetaOapg.properties.last_evaluated_factors: ...
                                                                        
                                                                        @typing.overload
                                                                        def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                                                                        
                                                                        def __getitem__(self, name: typing.Union[typing_extensions.Literal["last_evaluated_at", "last_evaluated_value", "last_evaluated_level", "last_evaluated_factors", ], str]):
                                                                            # dict_instance[name] accessor
                                                                            return super().__getitem__(name)
                                                                        
                                                                        
                                                                        @typing.overload
                                                                        def get_item_oapg(self, name: typing_extensions.Literal["last_evaluated_at"]) -> typing.Union[MetaOapg.properties.last_evaluated_at, schemas.Unset]: ...
                                                                        
                                                                        @typing.overload
                                                                        def get_item_oapg(self, name: typing_extensions.Literal["last_evaluated_value"]) -> typing.Union[MetaOapg.properties.last_evaluated_value, schemas.Unset]: ...
                                                                        
                                                                        @typing.overload
                                                                        def get_item_oapg(self, name: typing_extensions.Literal["last_evaluated_level"]) -> typing.Union[MetaOapg.properties.last_evaluated_level, schemas.Unset]: ...
                                                                        
                                                                        @typing.overload
                                                                        def get_item_oapg(self, name: typing_extensions.Literal["last_evaluated_factors"]) -> typing.Union[MetaOapg.properties.last_evaluated_factors, schemas.Unset]: ...
                                                                        
                                                                        @typing.overload
                                                                        def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                                                                        
                                                                        def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["last_evaluated_at", "last_evaluated_value", "last_evaluated_level", "last_evaluated_factors", ], str]):
                                                                            return super().get_item_oapg(name)
                                                                        
                                                                    
                                                                        def __new__(
                                                                            cls,
                                                                            *args: typing.Union[dict, frozendict.frozendict, ],
                                                                            last_evaluated_at: typing.Union[MetaOapg.properties.last_evaluated_at, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                                                            last_evaluated_value: typing.Union[MetaOapg.properties.last_evaluated_value, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                                                            last_evaluated_level: typing.Union[MetaOapg.properties.last_evaluated_level, str, schemas.Unset] = schemas.unset,
                                                                            last_evaluated_factors: typing.Union[MetaOapg.properties.last_evaluated_factors, list, tuple, schemas.Unset] = schemas.unset,
                                                                            _configuration: typing.Optional[schemas.Configuration] = None,
                                                                            **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                                                                        ) -> 'last_evaluated':
                                                                            return super().__new__(
                                                                                cls,
                                                                                *args,
                                                                                last_evaluated_at=last_evaluated_at,
                                                                                last_evaluated_value=last_evaluated_value,
                                                                                last_evaluated_level=last_evaluated_level,
                                                                                last_evaluated_factors=last_evaluated_factors,
                                                                                _configuration=_configuration,
                                                                                **kwargs,
                                                                            )
                                                                    expired_at = schemas.IntSchema
                                                                    
                                                                    
                                                                    class factors(
                                                                        schemas.ListSchema
                                                                    ):
                                                                    
                                                                    
                                                                        class MetaOapg:
                                                                            
                                                                            
                                                                            class items(
                                                                                schemas.DictSchema
                                                                            ):
                                                                            
                                                                            
                                                                                class MetaOapg:
                                                                                    
                                                                                    class properties:
                                                                                        name = schemas.StrSchema
                                                                                        value = schemas.StrSchema
                                                                                        type = schemas.StrSchema
                                                                                        source = schemas.StrSchema
                                                                                        description = schemas.StrSchema
                                                                                        
                                                                                        
                                                                                        class remediation(
                                                                                            schemas.DictSchema
                                                                                        ):
                                                                                        
                                                                                        
                                                                                            class MetaOapg:
                                                                                                
                                                                                                class properties:
                                                                                                    description = schemas.StrSchema
                                                                                                    url = schemas.StrSchema
                                                                                                    __annotations__ = {
                                                                                                        "description": description,
                                                                                                        "url": url,
                                                                                                    }
                                                                                            
                                                                                            @typing.overload
                                                                                            def __getitem__(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
                                                                                            
                                                                                            @typing.overload
                                                                                            def __getitem__(self, name: typing_extensions.Literal["url"]) -> MetaOapg.properties.url: ...
                                                                                            
                                                                                            @typing.overload
                                                                                            def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                                                                                            
                                                                                            def __getitem__(self, name: typing.Union[typing_extensions.Literal["description", "url", ], str]):
                                                                                                # dict_instance[name] accessor
                                                                                                return super().__getitem__(name)
                                                                                            
                                                                                            
                                                                                            @typing.overload
                                                                                            def get_item_oapg(self, name: typing_extensions.Literal["description"]) -> typing.Union[MetaOapg.properties.description, schemas.Unset]: ...
                                                                                            
                                                                                            @typing.overload
                                                                                            def get_item_oapg(self, name: typing_extensions.Literal["url"]) -> typing.Union[MetaOapg.properties.url, schemas.Unset]: ...
                                                                                            
                                                                                            @typing.overload
                                                                                            def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                                                                                            
                                                                                            def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["description", "url", ], str]):
                                                                                                return super().get_item_oapg(name)
                                                                                            
                                                                                        
                                                                                            def __new__(
                                                                                                cls,
                                                                                                *args: typing.Union[dict, frozendict.frozendict, ],
                                                                                                description: typing.Union[MetaOapg.properties.description, str, schemas.Unset] = schemas.unset,
                                                                                                url: typing.Union[MetaOapg.properties.url, str, schemas.Unset] = schemas.unset,
                                                                                                _configuration: typing.Optional[schemas.Configuration] = None,
                                                                                                **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                                                                                            ) -> 'remediation':
                                                                                                return super().__new__(
                                                                                                    cls,
                                                                                                    *args,
                                                                                                    description=description,
                                                                                                    url=url,
                                                                                                    _configuration=_configuration,
                                                                                                    **kwargs,
                                                                                                )
                                                                                        __annotations__ = {
                                                                                            "name": name,
                                                                                            "value": value,
                                                                                            "type": type,
                                                                                            "source": source,
                                                                                            "description": description,
                                                                                            "remediation": remediation,
                                                                                        }
                                                                                
                                                                                @typing.overload
                                                                                def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
                                                                                
                                                                                @typing.overload
                                                                                def __getitem__(self, name: typing_extensions.Literal["value"]) -> MetaOapg.properties.value: ...
                                                                                
                                                                                @typing.overload
                                                                                def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
                                                                                
                                                                                @typing.overload
                                                                                def __getitem__(self, name: typing_extensions.Literal["source"]) -> MetaOapg.properties.source: ...
                                                                                
                                                                                @typing.overload
                                                                                def __getitem__(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
                                                                                
                                                                                @typing.overload
                                                                                def __getitem__(self, name: typing_extensions.Literal["remediation"]) -> MetaOapg.properties.remediation: ...
                                                                                
                                                                                @typing.overload
                                                                                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                                                                                
                                                                                def __getitem__(self, name: typing.Union[typing_extensions.Literal["name", "value", "type", "source", "description", "remediation", ], str]):
                                                                                    # dict_instance[name] accessor
                                                                                    return super().__getitem__(name)
                                                                                
                                                                                
                                                                                @typing.overload
                                                                                def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> typing.Union[MetaOapg.properties.name, schemas.Unset]: ...
                                                                                
                                                                                @typing.overload
                                                                                def get_item_oapg(self, name: typing_extensions.Literal["value"]) -> typing.Union[MetaOapg.properties.value, schemas.Unset]: ...
                                                                                
                                                                                @typing.overload
                                                                                def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> typing.Union[MetaOapg.properties.type, schemas.Unset]: ...
                                                                                
                                                                                @typing.overload
                                                                                def get_item_oapg(self, name: typing_extensions.Literal["source"]) -> typing.Union[MetaOapg.properties.source, schemas.Unset]: ...
                                                                                
                                                                                @typing.overload
                                                                                def get_item_oapg(self, name: typing_extensions.Literal["description"]) -> typing.Union[MetaOapg.properties.description, schemas.Unset]: ...
                                                                                
                                                                                @typing.overload
                                                                                def get_item_oapg(self, name: typing_extensions.Literal["remediation"]) -> typing.Union[MetaOapg.properties.remediation, schemas.Unset]: ...
                                                                                
                                                                                @typing.overload
                                                                                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                                                                                
                                                                                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["name", "value", "type", "source", "description", "remediation", ], str]):
                                                                                    return super().get_item_oapg(name)
                                                                                
                                                                            
                                                                                def __new__(
                                                                                    cls,
                                                                                    *args: typing.Union[dict, frozendict.frozendict, ],
                                                                                    name: typing.Union[MetaOapg.properties.name, str, schemas.Unset] = schemas.unset,
                                                                                    value: typing.Union[MetaOapg.properties.value, str, schemas.Unset] = schemas.unset,
                                                                                    type: typing.Union[MetaOapg.properties.type, str, schemas.Unset] = schemas.unset,
                                                                                    source: typing.Union[MetaOapg.properties.source, str, schemas.Unset] = schemas.unset,
                                                                                    description: typing.Union[MetaOapg.properties.description, str, schemas.Unset] = schemas.unset,
                                                                                    remediation: typing.Union[MetaOapg.properties.remediation, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
                                                                                    _configuration: typing.Optional[schemas.Configuration] = None,
                                                                                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                                                                                ) -> 'items':
                                                                                    return super().__new__(
                                                                                        cls,
                                                                                        *args,
                                                                                        name=name,
                                                                                        value=value,
                                                                                        type=type,
                                                                                        source=source,
                                                                                        description=description,
                                                                                        remediation=remediation,
                                                                                        _configuration=_configuration,
                                                                                        **kwargs,
                                                                                    )
                                                                    
                                                                        def __new__(
                                                                            cls,
                                                                            arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]], typing.List[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]]],
                                                                            _configuration: typing.Optional[schemas.Configuration] = None,
                                                                        ) -> 'factors':
                                                                            return super().__new__(
                                                                                cls,
                                                                                arg,
                                                                                _configuration=_configuration,
                                                                            )
                                                                    
                                                                        def __getitem__(self, i: int) -> MetaOapg.items:
                                                                            return super().__getitem__(i)
                                                                    __annotations__ = {
                                                                        "value": value,
                                                                        "level": level,
                                                                        "status": status,
                                                                        "last_evaluated": last_evaluated,
                                                                        "expired_at": expired_at,
                                                                        "factors": factors,
                                                                    }
                                                            
                                                            @typing.overload
                                                            def __getitem__(self, name: typing_extensions.Literal["value"]) -> MetaOapg.properties.value: ...
                                                            
                                                            @typing.overload
                                                            def __getitem__(self, name: typing_extensions.Literal["level"]) -> MetaOapg.properties.level: ...
                                                            
                                                            @typing.overload
                                                            def __getitem__(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
                                                            
                                                            @typing.overload
                                                            def __getitem__(self, name: typing_extensions.Literal["last_evaluated"]) -> MetaOapg.properties.last_evaluated: ...
                                                            
                                                            @typing.overload
                                                            def __getitem__(self, name: typing_extensions.Literal["expired_at"]) -> MetaOapg.properties.expired_at: ...
                                                            
                                                            @typing.overload
                                                            def __getitem__(self, name: typing_extensions.Literal["factors"]) -> MetaOapg.properties.factors: ...
                                                            
                                                            @typing.overload
                                                            def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                                                            
                                                            def __getitem__(self, name: typing.Union[typing_extensions.Literal["value", "level", "status", "last_evaluated", "expired_at", "factors", ], str]):
                                                                # dict_instance[name] accessor
                                                                return super().__getitem__(name)
                                                            
                                                            
                                                            @typing.overload
                                                            def get_item_oapg(self, name: typing_extensions.Literal["value"]) -> typing.Union[MetaOapg.properties.value, schemas.Unset]: ...
                                                            
                                                            @typing.overload
                                                            def get_item_oapg(self, name: typing_extensions.Literal["level"]) -> typing.Union[MetaOapg.properties.level, schemas.Unset]: ...
                                                            
                                                            @typing.overload
                                                            def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> typing.Union[MetaOapg.properties.status, schemas.Unset]: ...
                                                            
                                                            @typing.overload
                                                            def get_item_oapg(self, name: typing_extensions.Literal["last_evaluated"]) -> typing.Union[MetaOapg.properties.last_evaluated, schemas.Unset]: ...
                                                            
                                                            @typing.overload
                                                            def get_item_oapg(self, name: typing_extensions.Literal["expired_at"]) -> typing.Union[MetaOapg.properties.expired_at, schemas.Unset]: ...
                                                            
                                                            @typing.overload
                                                            def get_item_oapg(self, name: typing_extensions.Literal["factors"]) -> typing.Union[MetaOapg.properties.factors, schemas.Unset]: ...
                                                            
                                                            @typing.overload
                                                            def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                                                            
                                                            def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["value", "level", "status", "last_evaluated", "expired_at", "factors", ], str]):
                                                                return super().get_item_oapg(name)
                                                            
                                                        
                                                            def __new__(
                                                                cls,
                                                                *args: typing.Union[dict, frozendict.frozendict, ],
                                                                value: typing.Union[MetaOapg.properties.value, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                                                level: typing.Union[MetaOapg.properties.level, str, schemas.Unset] = schemas.unset,
                                                                status: typing.Union[MetaOapg.properties.status, str, schemas.Unset] = schemas.unset,
                                                                last_evaluated: typing.Union[MetaOapg.properties.last_evaluated, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
                                                                expired_at: typing.Union[MetaOapg.properties.expired_at, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                                                factors: typing.Union[MetaOapg.properties.factors, list, tuple, schemas.Unset] = schemas.unset,
                                                                _configuration: typing.Optional[schemas.Configuration] = None,
                                                                **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                                                            ) -> 'trust':
                                                                return super().__new__(
                                                                    cls,
                                                                    *args,
                                                                    value=value,
                                                                    level=level,
                                                                    status=status,
                                                                    last_evaluated=last_evaluated,
                                                                    expired_at=expired_at,
                                                                    factors=factors,
                                                                    _configuration=_configuration,
                                                                    **kwargs,
                                                                )
                                                        
                                                        
                                                        class trustscore(
                                                            schemas.DictSchema
                                                        ):
                                                        
                                                        
                                                            class MetaOapg:
                                                                
                                                                class properties:
                                                                    entity_trustscore = schemas.IntSchema
                                                                    override_trustscore = schemas.IntSchema
                                                                    access_trustscore = schemas.IntSchema
                                                                    override_active = schemas.IntSchema
                                                                    trust_level = schemas.StrSchema
                                                                    updated_at = schemas.IntSchema
                                                                    __annotations__ = {
                                                                        "entity_trustscore": entity_trustscore,
                                                                        "override_trustscore": override_trustscore,
                                                                        "access_trustscore": access_trustscore,
                                                                        "override_active": override_active,
                                                                        "trust_level": trust_level,
                                                                        "updated_at": updated_at,
                                                                    }
                                                            
                                                            @typing.overload
                                                            def __getitem__(self, name: typing_extensions.Literal["entity_trustscore"]) -> MetaOapg.properties.entity_trustscore: ...
                                                            
                                                            @typing.overload
                                                            def __getitem__(self, name: typing_extensions.Literal["override_trustscore"]) -> MetaOapg.properties.override_trustscore: ...
                                                            
                                                            @typing.overload
                                                            def __getitem__(self, name: typing_extensions.Literal["access_trustscore"]) -> MetaOapg.properties.access_trustscore: ...
                                                            
                                                            @typing.overload
                                                            def __getitem__(self, name: typing_extensions.Literal["override_active"]) -> MetaOapg.properties.override_active: ...
                                                            
                                                            @typing.overload
                                                            def __getitem__(self, name: typing_extensions.Literal["trust_level"]) -> MetaOapg.properties.trust_level: ...
                                                            
                                                            @typing.overload
                                                            def __getitem__(self, name: typing_extensions.Literal["updated_at"]) -> MetaOapg.properties.updated_at: ...
                                                            
                                                            @typing.overload
                                                            def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                                                            
                                                            def __getitem__(self, name: typing.Union[typing_extensions.Literal["entity_trustscore", "override_trustscore", "access_trustscore", "override_active", "trust_level", "updated_at", ], str]):
                                                                # dict_instance[name] accessor
                                                                return super().__getitem__(name)
                                                            
                                                            
                                                            @typing.overload
                                                            def get_item_oapg(self, name: typing_extensions.Literal["entity_trustscore"]) -> typing.Union[MetaOapg.properties.entity_trustscore, schemas.Unset]: ...
                                                            
                                                            @typing.overload
                                                            def get_item_oapg(self, name: typing_extensions.Literal["override_trustscore"]) -> typing.Union[MetaOapg.properties.override_trustscore, schemas.Unset]: ...
                                                            
                                                            @typing.overload
                                                            def get_item_oapg(self, name: typing_extensions.Literal["access_trustscore"]) -> typing.Union[MetaOapg.properties.access_trustscore, schemas.Unset]: ...
                                                            
                                                            @typing.overload
                                                            def get_item_oapg(self, name: typing_extensions.Literal["override_active"]) -> typing.Union[MetaOapg.properties.override_active, schemas.Unset]: ...
                                                            
                                                            @typing.overload
                                                            def get_item_oapg(self, name: typing_extensions.Literal["trust_level"]) -> typing.Union[MetaOapg.properties.trust_level, schemas.Unset]: ...
                                                            
                                                            @typing.overload
                                                            def get_item_oapg(self, name: typing_extensions.Literal["updated_at"]) -> typing.Union[MetaOapg.properties.updated_at, schemas.Unset]: ...
                                                            
                                                            @typing.overload
                                                            def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                                                            
                                                            def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["entity_trustscore", "override_trustscore", "access_trustscore", "override_active", "trust_level", "updated_at", ], str]):
                                                                return super().get_item_oapg(name)
                                                            
                                                        
                                                            def __new__(
                                                                cls,
                                                                *args: typing.Union[dict, frozendict.frozendict, ],
                                                                entity_trustscore: typing.Union[MetaOapg.properties.entity_trustscore, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                                                override_trustscore: typing.Union[MetaOapg.properties.override_trustscore, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                                                access_trustscore: typing.Union[MetaOapg.properties.access_trustscore, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                                                override_active: typing.Union[MetaOapg.properties.override_active, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                                                trust_level: typing.Union[MetaOapg.properties.trust_level, str, schemas.Unset] = schemas.unset,
                                                                updated_at: typing.Union[MetaOapg.properties.updated_at, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                                                _configuration: typing.Optional[schemas.Configuration] = None,
                                                                **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                                                            ) -> 'trustscore':
                                                                return super().__new__(
                                                                    cls,
                                                                    *args,
                                                                    entity_trustscore=entity_trustscore,
                                                                    override_trustscore=override_trustscore,
                                                                    access_trustscore=access_trustscore,
                                                                    override_active=override_active,
                                                                    trust_level=trust_level,
                                                                    updated_at=updated_at,
                                                                    _configuration=_configuration,
                                                                    **kwargs,
                                                                )
                                                        
                                                        
                                                        class role_names(
                                                            schemas.ListSchema
                                                        ):
                                                        
                                                        
                                                            class MetaOapg:
                                                                items = schemas.StrSchema
                                                        
                                                            def __new__(
                                                                cls,
                                                                arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                                                                _configuration: typing.Optional[schemas.Configuration] = None,
                                                            ) -> 'role_names':
                                                                return super().__new__(
                                                                    cls,
                                                                    arg,
                                                                    _configuration=_configuration,
                                                                )
                                                        
                                                            def __getitem__(self, i: int) -> MetaOapg.items:
                                                                return super().__getitem__(i)
                                                        
                                                        
                                                        class emails(
                                                            schemas.ListSchema
                                                        ):
                                                        
                                                        
                                                            class MetaOapg:
                                                                items = schemas.StrSchema
                                                        
                                                            def __new__(
                                                                cls,
                                                                arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                                                                _configuration: typing.Optional[schemas.Configuration] = None,
                                                            ) -> 'emails':
                                                                return super().__new__(
                                                                    cls,
                                                                    arg,
                                                                    _configuration=_configuration,
                                                                )
                                                        
                                                            def __getitem__(self, i: int) -> MetaOapg.items:
                                                                return super().__getitem__(i)
                                                        number_of_users = schemas.IntSchema
                                                        __annotations__ = {
                                                            "trust": trust,
                                                            "trustscore": trustscore,
                                                            "role_names": role_names,
                                                            "emails": emails,
                                                            "number_of_users": number_of_users,
                                                        }
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["trust"]) -> MetaOapg.properties.trust: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["trustscore"]) -> MetaOapg.properties.trustscore: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["role_names"]) -> MetaOapg.properties.role_names: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["emails"]) -> MetaOapg.properties.emails: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["number_of_users"]) -> MetaOapg.properties.number_of_users: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                                                
                                                def __getitem__(self, name: typing.Union[typing_extensions.Literal["trust", "trustscore", "role_names", "emails", "number_of_users", ], str]):
                                                    # dict_instance[name] accessor
                                                    return super().__getitem__(name)
                                                
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["trust"]) -> typing.Union[MetaOapg.properties.trust, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["trustscore"]) -> typing.Union[MetaOapg.properties.trustscore, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["role_names"]) -> typing.Union[MetaOapg.properties.role_names, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["emails"]) -> typing.Union[MetaOapg.properties.emails, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["number_of_users"]) -> typing.Union[MetaOapg.properties.number_of_users, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                                                
                                                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["trust", "trustscore", "role_names", "emails", "number_of_users", ], str]):
                                                    return super().get_item_oapg(name)
                                                
                                            
                                                def __new__(
                                                    cls,
                                                    *args: typing.Union[dict, frozendict.frozendict, ],
                                                    trust: typing.Union[MetaOapg.properties.trust, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
                                                    trustscore: typing.Union[MetaOapg.properties.trustscore, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
                                                    role_names: typing.Union[MetaOapg.properties.role_names, list, tuple, schemas.Unset] = schemas.unset,
                                                    emails: typing.Union[MetaOapg.properties.emails, list, tuple, schemas.Unset] = schemas.unset,
                                                    number_of_users: typing.Union[MetaOapg.properties.number_of_users, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                                    _configuration: typing.Optional[schemas.Configuration] = None,
                                                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                                                ) -> 'extra_details':
                                                    return super().__new__(
                                                        cls,
                                                        *args,
                                                        trust=trust,
                                                        trustscore=trustscore,
                                                        role_names=role_names,
                                                        emails=emails,
                                                        number_of_users=number_of_users,
                                                        _configuration=_configuration,
                                                        **kwargs,
                                                    )
                                            __annotations__ = {
                                                "id": id,
                                                "serial_number": serial_number,
                                                "name": name,
                                                "model": model,
                                                "ownership": ownership,
                                                "platform": platform,
                                                "architechture": architechture,
                                                "source": source,
                                                "banned": banned,
                                                "os": os,
                                                "mdm_present": mdm_present,
                                                "mdm_vendor_name": mdm_vendor_name,
                                                "mdm_vendor_udid": mdm_vendor_udid,
                                                "mdm_compliant": mdm_compliant,
                                                "app_version": app_version,
                                                "created_at": created_at,
                                                "last_login": last_login,
                                                "extra_details": extra_details,
                                            }
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["serial_number"]) -> MetaOapg.properties.serial_number: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["model"]) -> MetaOapg.properties.model: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["ownership"]) -> MetaOapg.properties.ownership: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["platform"]) -> MetaOapg.properties.platform: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["architechture"]) -> MetaOapg.properties.architechture: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["source"]) -> MetaOapg.properties.source: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["banned"]) -> MetaOapg.properties.banned: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["os"]) -> MetaOapg.properties.os: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["mdm_present"]) -> MetaOapg.properties.mdm_present: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["mdm_vendor_name"]) -> MetaOapg.properties.mdm_vendor_name: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["mdm_vendor_udid"]) -> MetaOapg.properties.mdm_vendor_udid: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["mdm_compliant"]) -> MetaOapg.properties.mdm_compliant: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["app_version"]) -> MetaOapg.properties.app_version: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["created_at"]) -> MetaOapg.properties.created_at: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["last_login"]) -> MetaOapg.properties.last_login: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["extra_details"]) -> MetaOapg.properties.extra_details: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                                    
                                    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "serial_number", "name", "model", "ownership", "platform", "architechture", "source", "banned", "os", "mdm_present", "mdm_vendor_name", "mdm_vendor_udid", "mdm_compliant", "app_version", "created_at", "last_login", "extra_details", ], str]):
                                        # dict_instance[name] accessor
                                        return super().__getitem__(name)
                                    
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["serial_number"]) -> typing.Union[MetaOapg.properties.serial_number, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> typing.Union[MetaOapg.properties.name, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["model"]) -> typing.Union[MetaOapg.properties.model, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["ownership"]) -> typing.Union[MetaOapg.properties.ownership, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["platform"]) -> typing.Union[MetaOapg.properties.platform, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["architechture"]) -> typing.Union[MetaOapg.properties.architechture, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["source"]) -> typing.Union[MetaOapg.properties.source, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["banned"]) -> typing.Union[MetaOapg.properties.banned, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["os"]) -> typing.Union[MetaOapg.properties.os, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["mdm_present"]) -> typing.Union[MetaOapg.properties.mdm_present, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["mdm_vendor_name"]) -> typing.Union[MetaOapg.properties.mdm_vendor_name, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["mdm_vendor_udid"]) -> typing.Union[MetaOapg.properties.mdm_vendor_udid, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["mdm_compliant"]) -> typing.Union[MetaOapg.properties.mdm_compliant, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["app_version"]) -> typing.Union[MetaOapg.properties.app_version, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["created_at"]) -> typing.Union[MetaOapg.properties.created_at, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["last_login"]) -> typing.Union[MetaOapg.properties.last_login, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["extra_details"]) -> typing.Union[MetaOapg.properties.extra_details, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                                    
                                    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "serial_number", "name", "model", "ownership", "platform", "architechture", "source", "banned", "os", "mdm_present", "mdm_vendor_name", "mdm_vendor_udid", "mdm_compliant", "app_version", "created_at", "last_login", "extra_details", ], str]):
                                        return super().get_item_oapg(name)
                                    
                                
                                    def __new__(
                                        cls,
                                        *args: typing.Union[dict, frozendict.frozendict, ],
                                        id: typing.Union[MetaOapg.properties.id, str, schemas.Unset] = schemas.unset,
                                        serial_number: typing.Union[MetaOapg.properties.serial_number, str, schemas.Unset] = schemas.unset,
                                        name: typing.Union[MetaOapg.properties.name, str, schemas.Unset] = schemas.unset,
                                        model: typing.Union[MetaOapg.properties.model, str, schemas.Unset] = schemas.unset,
                                        ownership: typing.Union[MetaOapg.properties.ownership, str, schemas.Unset] = schemas.unset,
                                        platform: typing.Union[MetaOapg.properties.platform, str, schemas.Unset] = schemas.unset,
                                        architechture: typing.Union[MetaOapg.properties.architechture, str, schemas.Unset] = schemas.unset,
                                        source: typing.Union[MetaOapg.properties.source, str, schemas.Unset] = schemas.unset,
                                        banned: typing.Union[MetaOapg.properties.banned, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                        os: typing.Union[MetaOapg.properties.os, str, schemas.Unset] = schemas.unset,
                                        mdm_present: typing.Union[MetaOapg.properties.mdm_present, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                        mdm_vendor_name: typing.Union[MetaOapg.properties.mdm_vendor_name, str, schemas.Unset] = schemas.unset,
                                        mdm_vendor_udid: typing.Union[MetaOapg.properties.mdm_vendor_udid, str, schemas.Unset] = schemas.unset,
                                        mdm_compliant: typing.Union[MetaOapg.properties.mdm_compliant, str, schemas.Unset] = schemas.unset,
                                        app_version: typing.Union[MetaOapg.properties.app_version, str, schemas.Unset] = schemas.unset,
                                        created_at: typing.Union[MetaOapg.properties.created_at, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                        last_login: typing.Union[MetaOapg.properties.last_login, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                        extra_details: typing.Union[MetaOapg.properties.extra_details, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
                                        _configuration: typing.Optional[schemas.Configuration] = None,
                                        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                                    ) -> 'items':
                                        return super().__new__(
                                            cls,
                                            *args,
                                            id=id,
                                            serial_number=serial_number,
                                            name=name,
                                            model=model,
                                            ownership=ownership,
                                            platform=platform,
                                            architechture=architechture,
                                            source=source,
                                            banned=banned,
                                            os=os,
                                            mdm_present=mdm_present,
                                            mdm_vendor_name=mdm_vendor_name,
                                            mdm_vendor_udid=mdm_vendor_udid,
                                            mdm_compliant=mdm_compliant,
                                            app_version=app_version,
                                            created_at=created_at,
                                            last_login=last_login,
                                            extra_details=extra_details,
                                            _configuration=_configuration,
                                            **kwargs,
                                        )
                        
                            def __new__(
                                cls,
                                arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]], typing.List[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]]],
                                _configuration: typing.Optional[schemas.Configuration] = None,
                            ) -> 'devices':
                                return super().__new__(
                                    cls,
                                    arg,
                                    _configuration=_configuration,
                                )
                        
                            def __getitem__(self, i: int) -> MetaOapg.items:
                                return super().__getitem__(i)
                        count = schemas.IntSchema
                        __annotations__ = {
                            "devices": devices,
                            "count": count,
                        }
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["devices"]) -> MetaOapg.properties.devices: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["count"]) -> MetaOapg.properties.count: ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["devices", "count", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["devices"]) -> typing.Union[MetaOapg.properties.devices, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["count"]) -> typing.Union[MetaOapg.properties.count, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["devices", "count", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, ],
                    devices: typing.Union[MetaOapg.properties.devices, list, tuple, schemas.Unset] = schemas.unset,
                    count: typing.Union[MetaOapg.properties.count, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'data':
                    return super().__new__(
                        cls,
                        *args,
                        devices=devices,
                        count=count,
                        _configuration=_configuration,
                        **kwargs,
                    )
            __annotations__ = {
                "request_id": request_id,
                "error_code": error_code,
                "error_description": error_description,
                "data": data,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["request_id"]) -> MetaOapg.properties.request_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["error_code"]) -> MetaOapg.properties.error_code: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["error_description"]) -> MetaOapg.properties.error_description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["data"]) -> MetaOapg.properties.data: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["request_id", "error_code", "error_description", "data", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["request_id"]) -> typing.Union[MetaOapg.properties.request_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["error_code"]) -> typing.Union[MetaOapg.properties.error_code, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["error_description"]) -> typing.Union[MetaOapg.properties.error_description, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["data"]) -> typing.Union[MetaOapg.properties.data, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["request_id", "error_code", "error_description", "data", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        request_id: typing.Union[MetaOapg.properties.request_id, str, schemas.Unset] = schemas.unset,
        error_code: typing.Union[MetaOapg.properties.error_code, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        error_description: typing.Union[MetaOapg.properties.error_description, str, schemas.Unset] = schemas.unset,
        data: typing.Union[MetaOapg.properties.data, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SchemaFor200ResponseBodyApplicationJson':
        return super().__new__(
            cls,
            *args,
            request_id=request_id,
            error_code=error_code,
            error_description=error_description,
            data=data,
            _configuration=_configuration,
            **kwargs,
        )


@dataclass
class ApiResponseFor200(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor200ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_200 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor200,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor200ResponseBodyApplicationJson),
    },
)


@dataclass
class ApiResponseFor400(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: schemas.Unset = schemas.unset
    headers: schemas.Unset = schemas.unset


_response_for_400 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor400,
)


@dataclass
class ApiResponseFor401(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: schemas.Unset = schemas.unset
    headers: schemas.Unset = schemas.unset


_response_for_401 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor401,
)


@dataclass
class ApiResponseFor500(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: schemas.Unset = schemas.unset
    headers: schemas.Unset = schemas.unset


_response_for_500 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor500,
)
_status_code_to_response = {
    '200': _response_for_200,
    '400': _response_for_400,
    '401': _response_for_401,
    '500': _response_for_500,
}
_all_accept_content_types = (
    'application/json',
)


class BaseApi(api_client.Api):

    def _v2_devices_get_oapg(
        self: api_client.Api,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        """
         Get the Devices in an Organization
        :param skip_deserialization: If true then api_response.response will be set but
            api_response.body and api_response.headers will not be deserialized into schema
            class instances
        """
        self._verify_typed_dict_inputs_oapg(RequestQueryParams, query_params)
        used_path = path.value

        prefix_separator_iterator = None
        for parameter in (
            request_query_serial_number,
            request_query_email,
            request_query_name,
            request_query_model,
            request_query_platform,
            request_query_trust_level,
            request_query_id,
            request_query_ownership,
            request_query_source,
            request_query_architecture,
            request_query_os,
            request_query_mdm_present,
            request_query_mdm_vendor_name,
            request_query_banned,
            request_query_app_version,
            request_query_role_names,
            request_query_skip__default0,
            request_query_limit__default10,
            request_query_order__defaultdesc,
            request_query_order_by__defaultcreated_at,
            request_query_last_login_before,
            request_query_last_login_after,
            request_query_trustscore_status,
            request_query_exact_email,
            request_query_exact_serial_number,
        ):
            parameter_data = query_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            if prefix_separator_iterator is None:
                prefix_separator_iterator = parameter.get_prefix_separator_iterator()
            serialized_data = parameter.serialize(parameter_data, prefix_separator_iterator)
            for serialized_value in serialized_data.values():
                used_path += serialized_value

        _headers = HTTPHeaderDict()
        # TODO add cookie handling
        if accept_content_types:
            for accept_content_type in accept_content_types:
                _headers.add('Accept', accept_content_type)

        response = self.api_client.call_api(
            resource_path=used_path,
            method='get'.upper(),
            headers=_headers,
            auth_settings=_auth,
            stream=stream,
            timeout=timeout,
        )

        if skip_deserialization:
            api_response = api_client.ApiResponseWithoutDeserialization(response=response)
        else:
            response_for_status = _status_code_to_response.get(str(response.status))
            if response_for_status:
                api_response = response_for_status.deserialize(response, self.api_client.configuration)
            else:
                api_response = api_client.ApiResponseWithoutDeserialization(response=response)

        if not 200 <= response.status <= 299:
            raise exceptions.ApiException(api_response=api_response)

        return api_response


class V2DevicesGet(BaseApi):
    # this class is used by api classes that refer to endpoints with operationId fn names

    def v2_devices_get(
        self: BaseApi,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        return self._v2_devices_get_oapg(
            query_params=query_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


class ApiForget(BaseApi):
    # this class is used by api classes that refer to endpoints by path and http method names

    def get(
        self: BaseApi,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        return self._v2_devices_get_oapg(
            query_params=query_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )





# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from banyanclient.paths.v2_access_tier_access_tier_id_tunnel_config_tunnel_config_id import Api

from banyanclient.paths import PathValues

path = PathValues.V2_ACCESS_TIER_ACCESS_TIER_ID_TUNNEL_CONFIG_TUNNEL_CONFIG_ID


# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from banyanclient.apis.tag_to_api import tag_to_api

import enum


class TagValues(str, enum.Enum):
    ACCESS_TIER = "access_tier"
    REGISTERED_SERVICE = "registered_service"
    API_KEY = "api_key"
    AUDIT_LOG = "audit_log"
    BUNDLE = "bundle"
    CLOUD_RESOURCE = "cloud_resource"
    CLOUD_RESOURCE_SERVICE = "cloud_resource_service"
    DEVICE = "device"
    ENDUSER = "enduser"
    SECURITY_ROLE = "security_role"
    EVENT = "event"
    SAASAPP = "saasapp"
    SATELLITE = "satellite"
    SERVICE_TUNNEL = "service_tunnel"
    SECURITY_POLICY = "security_policy"



# coding: utf-8

"""
    Banyan Rest APIs

    This swagger spec contains list of all Banyan APIs.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

from banyanclient.paths.v2_cloud_resource_service.get import V2CloudResourceServiceGet
from banyanclient.paths.v2_cloud_resource_service_id.delete import V2CloudResourceServiceIdDelete
from banyanclient.paths.v2_cloud_resource_service_id.get import V2CloudResourceServiceIdGet
from banyanclient.paths.v2_cloud_resource_service.post import V2CloudResourceServicePost


class CloudResourceServiceApi(
    V2CloudResourceServiceGet,
    V2CloudResourceServiceIdDelete,
    V2CloudResourceServiceIdGet,
    V2CloudResourceServicePost,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    Banyan Rest APIs

    This swagger spec contains list of all Banyan APIs.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

from banyanclient.paths.v2_connector_stats.get import V2ConnectorStatsGet
from banyanclient.paths.v2_satellite.get import V2SatelliteGet
from banyanclient.paths.v2_satellite_id.delete import V2SatelliteIdDelete
from banyanclient.paths.v2_satellite_id.get import V2SatelliteIdGet
from banyanclient.paths.v2_satellite_id.put import V2SatelliteIdPut
from banyanclient.paths.v2_satellite.post import V2SatellitePost


class SatelliteApi(
    V2ConnectorStatsGet,
    V2SatelliteGet,
    V2SatelliteIdDelete,
    V2SatelliteIdGet,
    V2SatelliteIdPut,
    V2SatellitePost,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
